Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.GruppeAnsprechpartner Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.GruppeAnsprechpartner einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.GruppeAnsprechpartner) | Gemeinde_Modelle.GruppeAnsprechpartner |
__str__(self) (Definiert in Gemeinde_Modelle.GruppeAnsprechpartner) | Gemeinde_Modelle.GruppeAnsprechpartner |
R_gruppe (Definiert in Gemeinde_Modelle.GruppeAnsprechpartner) | Gemeinde_Modelle.GruppeAnsprechpartner | static
R_person (Definiert in Gemeinde_Modelle.GruppeAnsprechpartner) | Gemeinde_Modelle.GruppeAnsprechpartner | static